# This file exists only to transfer variables between the Flask server running in it.
# Say what you want, this is useful and I am going to continue to use it. Shaddup.

standard_url = "http://127.0.0.1:5000/"


last_request = None
modifier = None
